@@ -109,23 +109,23 @@ fn new_lines_ignored() {
         patches,
         vec![
             Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 0, 0, 0,]),
+                TreePath::new(vec![1, 0, 0, 0, 0, 0,]),
                 &leaf::text("0"),
                 &leaf::text("1")
             ),
             Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 2, 0, 0,]),
+                TreePath::new(vec![1, 0, 0, 2, 0, 0,]),
                 &leaf::text("2"),
                 &leaf::text("3")
             ),
             Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 3, 0, 0,]),
+                TreePath::new(vec![1, 0, 0, 3, 0, 0,]),
                 &leaf::text("3"),
                 &leaf::text("4")
             ),
             Patch::insert_node(
                 Some(&"div"),
-                TreePath::new(vec![0, 1, 0, 0, 0,]),
+                TreePath::new(vec![1, 0, 0, 0,]),
                 &div(
                     vec![class("grid__number__line")],
                     vec![
@@ -139,7 +139,7 @@ fn new_lines_ignored() {
             ),
             Patch::insert_node(
                 Some(&"div"),
-                TreePath::new(vec![0, 1, 0, 0, 2,]),
+                TreePath::new(vec![1, 0, 0, 2,]),
                 &div(
                     vec![class("grid__number__line")],
                     vec![
@@ -151,12 +151,9 @@ fn new_lines_ignored() {
                     ]
                 )
             ),
-            Patch::remove_node(
-                Some(&"div"),
-                TreePath::new(vec![0, 1, 0, 0, 1,]),
-            ),
+            Patch::remove_node(Some(&"div"), TreePath::new(vec![1, 0, 0, 1,]),),
             Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 1, 0,]),
+                TreePath::new(vec![1, 0, 1, 0,]),
                 &leaf::text("line: 0, column: 0"),
                 &leaf::text("line: 1, column: 0")
             ),
